summaryrefslogtreecommitdiffstats
path: root/tests
diff options
context:
space:
mode:
authorGravatar Robert C. Helling <helling@atdotde.de>2015-08-31 23:56:53 +0200
committerGravatar Dirk Hohndel <dirk@hohndel.org>2015-08-31 15:19:10 -0700
commit10d8a625d0966b748690325e82bd2b9278a5c7f4 (patch)
tree92c3bb19f1dc4651f9ec13774f4a3a7a2acd385f /tests
parente32896c2bc85a11c2eacc35c0267c2fa90d73b59 (diff)
downloadsubsurface-10d8a625d0966b748690325e82bd2b9278a5c7f4.tar.gz
Adopt expected times in TestPlan
Signed-off-by: Robert C. Helling <helling@atdotde.de> Signed-off-by: Dirk Hohndel <dirk@hohndel.org>
Diffstat (limited to 'tests')
-rw-r--r--tests/testplan.cpp16
1 files changed, 8 insertions, 8 deletions
diff --git a/tests/testplan.cpp b/tests/testplan.cpp
index 5cc149228..820d391e1 100644
--- a/tests/testplan.cpp
+++ b/tests/testplan.cpp
@@ -323,8 +323,8 @@ void TestPlan::testVpmbMetric60m30minAir()
// print first ceiling
printf("First ceiling %.1f m\n", (mbar_to_depth(first_ceiling_pressure.mbar, &displayed_dive) * 0.001));
- // check benchmark run time of 141 minutes, and known Subsurface runtime of 139 minutes
- QVERIFY(compareDecoTime(displayed_dive.dc.duration.seconds, 141u * 60u + 20u, 139u * 60u + 20u));
+ // check benchmark run time of 141 minutes, and known Subsurface runtime of 138 minutes
+ QVERIFY(compareDecoTime(displayed_dive.dc.duration.seconds, 141u * 60u + 20u, 138u * 60u + 20u));
}
void TestPlan::testVpmbMetric60m30minEan50()
@@ -425,8 +425,8 @@ void TestPlan::testVpmbMetric100m60min()
QCOMPARE(ev->gas.index, 2);
QCOMPARE(ev->value, 100);
QCOMPARE(get_depth_at_time(&displayed_dive.dc, ev->time.seconds), 6000);
- // check benchmark run time of 311 minutes, and known Subsurface runtime of 312 minutes
- QVERIFY(compareDecoTime(displayed_dive.dc.duration.seconds, 311u * 60u + 20u, 312u * 60u + 20u));
+ // check benchmark run time of 311 minutes, and known Subsurface runtime of 313 minutes
+ QVERIFY(compareDecoTime(displayed_dive.dc.duration.seconds, 311u * 60u + 20u, 313u * 60u + 20u));
}
void TestPlan::testVpmbMetricMultiLevelAir()
@@ -451,8 +451,8 @@ void TestPlan::testVpmbMetricMultiLevelAir()
// print first ceiling
printf("First ceiling %.1f m\n", (mbar_to_depth(first_ceiling_pressure.mbar, &displayed_dive) * 0.001));
- // check benchmark run time of 167 minutes, and known Subsurface runtime of 168 minutes
- QVERIFY(compareDecoTime(displayed_dive.dc.duration.seconds, 167u * 60u + 20u, 168u * 60u + 20u));
+ // check benchmark run time of 167 minutes, and known Subsurface runtime of 167 minutes
+ QVERIFY(compareDecoTime(displayed_dive.dc.duration.seconds, 167u * 60u + 20u, 167u * 60u + 20u));
}
void TestPlan::testVpmbMetric100m10min()
@@ -489,8 +489,8 @@ void TestPlan::testVpmbMetric100m10min()
QCOMPARE(ev->gas.index, 2);
QCOMPARE(ev->value, 100);
QCOMPARE(get_depth_at_time(&displayed_dive.dc, ev->time.seconds), 6000);
- // check benchmark run time of 58 minutes, and known Subsurface runtime of 57 minutes
- QVERIFY(compareDecoTime(displayed_dive.dc.duration.seconds, 58u * 60u + 20u, 57u * 60u + 20u));
+ // check benchmark run time of 58 minutes, and known Subsurface runtime of 56 minutes
+ QVERIFY(compareDecoTime(displayed_dive.dc.duration.seconds, 58u * 60u + 20u, 56u * 60u + 20u));
}
QTEST_MAIN(TestPlan)